# The climate finance package


_**climate-finance** is the python package to get, clean, and work with international public climate finance._ 

You can use this package to get, rebuild, remix, and create using our tools and methodologies — all with only a few lines of code.

Climate finance data is notoriously difficult to work with. It's messy - really messy - and comes in all sorts of shapes and sizes, scattered across multiple websites.

It took us months to understand which climate finance data to use, and even longer to clean the data ready for the Climate Finance Files. 

We don't think you should have to do this too. 

We have built **climate-finance** to lower the barriers to access that many organisations face when seeking to conduct research or advocacy on these topics. For too long, bad data has restricted climate accoutability. 
And for too long, global leaders have capitalised on bad data to dictate the narrative on climate finance. 

We hope these tools equip everyone with the data to hold global leaders accountable in the fight against climate change. As currently, they are not doing enough. 

## Come back soon
The content on this repository is an alpha version we have used in our research. We're creating friendlier ways to use the package, which don't involve looking through all the code.
We are planning a first release in December 2023.

## Questions? Would like to collaborate?
We want this package to help others analyse climate finance data. If you want to collaborate, or have any questions, please reach out.

